@@ -27,25 +27,12 @@ epi.conf(tmp, ctype = "inc.rate", method = "exact", N = 1000, design = 1,
    conf.level = 0.95) * 1000
 
 ## -----------------------------------------------------------------------------
-tmp <- epi.betabuster(mode = 0.60, conf = 0.80, greaterthan = TRUE, x = 0.35, 
-   conf.level = 0.95, max.shape1 = 100, step = 0.001)
-tmp$shape1; tmp$shape2
-
-## ----dfreq01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:dfreq01}Frequency histogram of disease prevalence estimates for our simulated population."----
-dprob <- rbeta(n = 25, shape1 = tmp$shape1, shape2 = tmp$shape2)
-dat.df <- data.frame(dprob = dprob)
-
-ggplot(data = dat.df, aes(x = dprob)) +
-  theme_bw() +
-  geom_histogram(binwidth = 0.01, colour = "gray", fill = "dark blue", size = 0.1) +
-  scale_x_continuous(limits = c(0,1), name = "Prevalence") +
-  scale_y_continuous(limits = c(0,10), name = "Number of draws")
+ncas <- c(347,444,145,156,56,618,203,113,10,30,663,447,213,52,256,216,745,97,31,250,430,494,96,544,352)
+npop <- c(477,515,1114,625,69,1301,309,840,68,100,1375,1290,1289,95,307,354,1393,307,35,364,494,1097,261,615,508)
+rname <- paste("Region ", 1:length(npop), sep = "")
+dat.df <- data.frame(rname,ncas,npop)
 
 ## -----------------------------------------------------------------------------
-dat.df$rname <- paste("Region ", 1:25, sep = "")
-dat.df$npop <- round(runif(n = 25, min = 20, max = 1500), digits = 0)
-dat.df$ncas <- round(dat.df$dprob * dat.df$npop, digits = 0)
-
 tmp <- as.matrix(cbind(dat.df$ncas, dat.df$npop))
 tmp <- epi.conf(tmp, ctype = "prevalence", method = "exact", N = 1000, design = 1, 
    conf.level = 0.95) * 100
@@ -67,7 +54,7 @@ ggplot(data = dat.df, aes(x = rank, y = est)) +
 
 ## -----------------------------------------------------------------------------
 n.males <- 100; n.females <- 50
-odate <- seq(from = as.Date("2004-07-26"), to = as.Date("2004-12-13"), by = 1)
+odate <- seq(from = as.Date("2022-07-26"), to = as.Date("2022-12-13"), by = 1)
 prob <- c(1:100, 41:1); prob <- prob / sum(prob)
 modate <- sample(x = odate, size = n.males, replace = TRUE, p = prob)
 fodate <- sample(x = odate, size = n.females, replace = TRUE)
@@ -78,71 +65,71 @@ dat.df <- data.frame(sex = c(rep("Male", n.males), rep("Female", n.females)),
 # Sort the data in order of odate:
 dat.df <- dat.df[sort.list(dat.df$odate),] 
 
-## ----epicurve01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve01}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004."----
+## ----epicurve01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve01}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022."----
 ggplot(data = dat.df, aes(x = as.Date(odate))) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", size = 0.1) +
+  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("7 days"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
-## ----epicurve02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve02}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004. Superimposed on this plot is a smoothed estimate of case density."----
+## ----epicurve02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve02}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022. Superimposed on this plot is a smoothed estimate of case density."----
 
 ggplot(data = dat.df, aes(x = odate)) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", size = 0.1) +
+  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
   geom_density(aes(y = after_stat(density) * (nrow(dat.df) * 7)), colour = "red") +
   scale_x_date(breaks = date_breaks("7 days"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
 
-## ----epicurve03-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve03}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004, conditioned by sex."----
+## ----epicurve03-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve03}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022, conditioned by sex."----
 ggplot(data = dat.df, aes(x = as.Date(odate))) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", size = 0.1) +
+  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
   facet_grid( ~ sex)
 
-## ----epicurve04-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve04}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004, conditioned by sex. An event that occurred on 31 October 2004 is indicated by the vertical dashed line."----
+## ----epicurve04-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve04}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022, conditioned by sex. An event that occurred on 31 October 2022 is indicated by the vertical dashed line."----
 ggplot(data = dat.df, aes(x = as.Date(odate))) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", size = 0.1) +
+  geom_histogram(binwidth = 7, colour = "gray", fill = "dark blue", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
   facet_grid( ~ sex) +
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2004", format = "%d/%m/%Y"))), 
+  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2022", format = "%d/%m/%Y"))), 
    linetype = "dashed")
 
-## ----epicurve05-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve05}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004, grouped by sex."----
+## ----epicurve05-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve05}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022, grouped by sex."----
 ggplot(data = dat.df, aes(x = as.Date(odate), group = sex, fill = sex)) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", size = 0.1) +
+  geom_histogram(binwidth = 7, colour = "gray", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2004", format = "%d/%m/%Y"))), 
+  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2022", format = "%d/%m/%Y"))), 
    linetype = "dashed") + 
   scale_fill_manual(values = c("#d46a6a", "#738ca6"), name = "Sex") +
   theme(legend.position = c(0.90, 0.80))
 
-## ----epicurve06-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve06}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2004, grouped by sex."----
+## ----epicurve06-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve06}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 26 July to 13 December 2022, grouped by sex."----
 ggplot(data = dat.df, aes(x = as.Date(odate), group = sex, fill = sex)) +
   theme_bw() +
-  geom_histogram(binwidth = 7, colour = "gray", size = 0.1, position = "dodge") +
+  geom_histogram(binwidth = 7, colour = "gray", linewidth = 0.1, position = "dodge") +
   scale_x_date(breaks = date_breaks("1 week"), labels = date_format("%d %b"), 
      name = "Date") +
-  scale_y_continuous(breaks = seq(from = 0, to = 20, by = 2), limits = c(0,20), name = "Number of cases") +
+  scale_y_continuous(breaks = seq(from = 0, to = 30, by = 5), limits = c(0,30), name = "Number of cases") +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
-  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2004", format = "%d/%m/%Y"))), 
+  geom_vline(aes(xintercept = as.numeric(as.Date("31/10/2022", format = "%d/%m/%Y"))), 
    linetype = "dashed") + 
   scale_fill_manual(values = c("#d46a6a", "#738ca6"), name = "Sex") + 
   theme(legend.position = c(0.90, 0.80))
@@ -162,7 +149,7 @@ head(dat.df)
 ## ----epicurve07-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:epicurve07}Frequency histogram showing counts of incident cases of disease as a function of calendar date, 24 February 2020 to 20 July 2020."----
 ggplot() +
   theme_bw() +
-  geom_histogram(dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", size = 0.1) +
+  geom_histogram(dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", linewidth = 0.1) +
   scale_x_date(breaks = date_breaks("2 weeks"), labels = date_format("%b %Y"), 
      name = "Date") +
   scale_y_continuous(limits = c(0,125), name = "Number of cases") +
@@ -175,7 +162,7 @@ max(cumsum(dat.df$ncas))
 
 ggplot() +
   theme_bw() +
-  geom_histogram(data = dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", size = 0.1) +
+  geom_histogram(data = dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", linewidth = 0.1) +
   geom_line(data = dat.df, mapping = aes(x = edate, y = cumsum(ncas) / 15)) + 
   scale_x_date(breaks = date_breaks("2 weeks"), labels = date_format("%b %Y"), 
      name = "Date") +
@@ -190,8 +177,8 @@ dat.df$rncas <- rollmean(x = dat.df$ncas, k = 5, fill = NA)
 
 ggplot() +
   theme_bw() +
-  geom_histogram(data = dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", size = 0.1) +
-  geom_line(data = dat.df, mapping = aes(x = edate, y = dat.df$rncas), colour = "red") + 
+  geom_histogram(data = dat.df, mapping = aes(x = edate, weight = ncas), binwidth = 1, fill = "#738ca6", colour = "grey", linewidth = 0.1) +
+  geom_line(data = dat.df, mapping = aes(x = edate, y = rncas), colour = "red") + 
   scale_x_date(breaks = date_breaks("2 weeks"), labels = date_format("%b %Y"), 
      name = "Date") +
   scale_y_continuous(limits = c(0,125), name = "Number of cases") +
@@ -199,42 +186,41 @@ ggplot() +
   theme(axis.text.x = element_text(angle = 90, hjust = 1))
 
 ## ----message = FALSE, warning = FALSE-----------------------------------------
-library(sf); library(spData); library(rgdal); library(plyr); library(RColorBrewer); library(spatstat)
+library(sf); library(spData); library(plyr); library(RColorBrewer); library(sp); library(spatstat)
 
-ncsids.sf <- st_read(dsn = system.file("shapes/sids.shp", package = "spData")[1])
-ncsids.sf <- ncsids.sf[,c("BIR74","SID74")]
-head(ncsids.sf)
+ncsidsll.sf <- st_read(dsn = system.file("shapes/sids.shp", package = "spData")[1])
+ncsidsll.sf <- ncsidsll.sf[,c("BIR74","SID74")]
+head(ncsidsll.sf)
 
 ## ----spatial01-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:spatial01}Map of North Carolina, USA showing the number of sudden infant death syndrome cases, by county for 1974."----
 ggplot() + 
    theme_bw() +
-   geom_sf(data = ncsids.sf, aes(fill = SID74), colour = "dark grey") + 
+   geom_sf(data = ncsidsll.sf, aes(fill = SID74), colour = "dark grey") + 
    scale_fill_gradientn(limits = c(0,60), colours = brewer.pal(n = 5, "Reds"), guide = "colourbar") +
    scale_x_continuous(name = "Longitude") +
    scale_y_continuous(name = "Latitude") +
    labs(fill = "SIDS 1974")
 
 ## ----message = FALSE----------------------------------------------------------
-data(epi.incin); incin.df <- epi.incin
-incin.df$status <- factor(incin.df$status, levels = c(0,1), labels = c("Neg", "Pos"))
-names(incin.df)[3] <- "Status"
+data(chorley)
+chorley.df <- data.frame(xcoord = chorley$x * 1000, ycoord = chorley$y * 1000, status = chorley$marks)
+chorley.df$status <- factor(chorley.df$status, levels = c("lung","larynx"), labels = c("Lung","Larynx"))
 
-incin.sf <- st_as_sf(incin.df, coords = c("xcoord","ycoord"), remove = FALSE)
-st_crs(incin.sf) <- 27700
+chlarynxbng.sf <- st_as_sf(chorley.df, coords = c("xcoord","ycoord"), remove = FALSE)
+st_crs(chlarynxbng.sf) <- 27700
 
-coppull.ow <- convexhull.xy(x = incin.df[,1], y = incin.df[,2])
-coppull.ow <- dilation(coppull.ow, r = 1000)
+chlarynxbng.ow <- chorley$window
 
 ## -----------------------------------------------------------------------------
-coords <- matrix(c(coppull.ow$bdry[[1]]$x, coppull.ow$bdry[[1]]$y), ncol = 2, byrow = FALSE)
+coords <- matrix(c(chlarynxbng.ow$bdry[[1]]$x * 1000, chlarynxbng.ow$bdry[[1]]$y * 1000), ncol = 2, byrow = FALSE)
 pol <- Polygon(coords, hole = FALSE)
 pol <- Polygons(list(pol),1)
 pol <- SpatialPolygons(list(pol))
-coppull.spdf <- SpatialPolygonsDataFrame(Sr = pol, data = data.frame(id = 1), match.ID = TRUE)
+chpolbng.spdf <- SpatialPolygonsDataFrame(Sr = pol, data = data.frame(id = 1), match.ID = TRUE)
 
 ## -----------------------------------------------------------------------------
-coppull.sf <- as(coppull.spdf, "sf")
-st_crs(coppull.sf) <- 27700
+chpolbng.sf <- as(chpolbng.spdf, "sf")
+st_crs(chpolbng.sf) <- 27700
 
 ## -----------------------------------------------------------------------------
 mformat <- function(){
@@ -243,14 +229,13 @@ mformat <- function(){
 
 ## ----spatial02-fig, warnings = FALSE, echo = TRUE, fig.cap="\\label{fig:spatial02}Point map showing the place of residence of individuals diagnosed with laryngeal cancer (Pos) and lung cancer (Neg), Copull Lancashire, UK, 1972 to 1980."----
 ggplot() +
-   theme_bw() +
-   geom_sf(data = incin.sf, aes(colour = Status, shape = Status)) +
-   geom_sf(data = coppull.sf, fill = "transparent", colour = "black") +
-   coord_sf(datum = st_crs(coppull.sf)) +
-   scale_colour_manual(values = c("grey","red")) +
-   scale_shape_manual(values = c(1,16)) +
-   scale_x_continuous(name = "Easting (km)", labels = mformat()) +
-   scale_y_continuous(name = "Northing (km)", labels = mformat()) +
-    theme(legend.position = c(0.10, 0.15))
-
+  theme_bw() +
+  geom_sf(data = chlarynxbng.sf, aes(colour = status, shape = status)) +
+  geom_sf(data = chpolbng.sf, fill = "transparent", colour = "black") +
+  coord_sf(datum = st_crs(chpolbng.sf)) +
+  scale_colour_manual(name = "Type", values = c("grey","red")) +
+  scale_shape_manual(name = "Type", values = c(1,16)) +
+  scale_x_continuous(name = "Easting (km)", labels = mformat()) +
+  scale_y_continuous(name = "Northing (km)", labels = mformat()) +
+  theme(legend.position = c(0.10, 0.12))
 
